import javax.swing.*;
import java.awt.*;

public class DrawingAircraftCarrier extends JPanel {
    private EntityAircraftCarrier entityAircraftCarrier;
    public EntityAircraftCarrier getEntityAircraftCarrier(){
        return entityAircraftCarrier;
    }
    private int _pictureWidth;
    private int _pictureHeight;
    private int _startPosX;
    private int _startPosY;
    private final int _PlaneWidth = 164;
    private final int _PlaneHeight = 40;
    private DrawingImprovements drawingImprovements;
    public boolean init(int speed, double weight, Color bodyColor, Color
            additionalColor, boolean Cabin, boolean Runway, int width, int height, int improvementsNumber)
    {
        if (_PlaneWidth > width || _PlaneHeight > height)
            return  false;
        _pictureWidth = width;
        _pictureHeight = height;
        entityAircraftCarrier = new EntityAircraftCarrier();
        entityAircraftCarrier.init(speed, weight, bodyColor, additionalColor,
                Cabin, Runway);
        drawingImprovements = new DrawingImprovements();
        drawingImprovements.setNumber(improvementsNumber);
        return true;
    }
    public void setPosition(int x, int y)
    {
        if (_startPosX > (_pictureWidth - _PlaneWidth) || _startPosY>(_pictureHeight - _PlaneHeight) || x <= 0 || y <= 0)
            x = y = 2;
        _startPosX = x;
        _startPosY = y;
    }
    public void moveTransport(DirectionType direction)
    {
        if (entityAircraftCarrier == null)
            return;
        int step = entityAircraftCarrier.step.get().intValue();
        switch (direction)
        {
            case LEFT:
                if (_startPosX - step > 0)
                    _startPosX -= step;
                break;
            case UP:
                if (_startPosY - step > 0)
                    _startPosY -= step;
                break;
            case RIGHT:
                if (_startPosX + _PlaneWidth + step < _pictureWidth)
                    _startPosX += step;
                break;
            case DOWN:
                if (_startPosY + _PlaneHeight + step < _pictureHeight)
                    _startPosY += step;
                break;
        }
    }
    public void drawTransport(Graphics gr)
    {
        super.paintComponent(gr);
        Graphics2D g = (Graphics2D) gr;
        if (entityAircraftCarrier == null)
            return;
        Color penColor = Color.BLACK;
        Color bodyColor = entityAircraftCarrier.getBodyColor();
        Color additionalColor = entityAircraftCarrier.getAdditionalColor();
        g.setColor(penColor);
        g.drawLine(_startPosX+4, _startPosY, _startPosX + 124, _startPosY);
        g.drawLine(_startPosX+124, _startPosY, _startPosX + 164, _startPosY+20);
        g.drawLine(_startPosX + 164, _startPosY+20, _startPosX + 124, _startPosY + 40);
        g.drawLine(_startPosX + 164, _startPosY + 20, _startPosX + 124, _startPosY + 40);
        g.drawLine(_startPosX + 124, _startPosY + 40, _startPosX + 4, _startPosY + 40);
        g.drawLine(_startPosX+4, _startPosY + 40, _startPosX + 4, _startPosY);
        g.setColor(bodyColor);
        g.fillRect(_startPosX, _startPosY + 6, 4, 12);
        g.fillRect(_startPosX, _startPosY + 24, 4, 12);
        g.setColor(penColor);
        g.drawOval(_startPosX + 115, _startPosY + 13, 14, 14);
        g.drawRect(_startPosX + 63, _startPosY + 13, 27, 14);
        g.drawRect(_startPosX + 90, _startPosY + 9, 14, 22);
        if(entityAircraftCarrier.getRunway()){
            g.setColor(additionalColor);
            g.fillRect(_startPosX + 4, _startPosY + 13, 59, 14);
            g.setColor(Color.WHITE);
            g.drawLine(_startPosX + 62, _startPosY + 19, _startPosX + 52, _startPosY + 19);
            g.drawLine(_startPosX + 47, _startPosY + 19, _startPosX + 37, _startPosY + 19);
            g.drawLine(_startPosX + 32, _startPosY + 19, _startPosX + 22, _startPosY + 19);
            g.drawLine(_startPosX + 17, _startPosY + 19, _startPosX + 7, _startPosY + 19);
        }
        if (entityAircraftCarrier.getCabin())
        {
            g.setColor(additionalColor);
            g.fillRect(_startPosX + 90, _startPosY, 15, 9);
        }
        g.setColor(bodyColor);
        drawingImprovements.drawEngines(g, _startPosX, _startPosY);
    }
}